/*
 * linux/include/asm-arm/arch-ebsa/hardware.h
 *
 * Copyright (C) 1996 Russell King.
 *
 * This file contains the hardware definitions of the Corel VNC
 */

#ifndef __ASM_ARCH_HARDWARE_H
#define __ASM_ARCH_HARDWARE_H


/*
 * What hardware must be present
 */

/* handy sizes */
#define SZ_1K                           0x00000400
#define SZ_16K                          0x00004000
#define SZ_64K                          0x00010000
#define SZ_256K                         0x00040000
#define SZ_512K                         0x00080000

#define SZ_1M                           0x00100000
#define SZ_2M                           0x00200000
#define SZ_4M                           0x00400000
#define SZ_8M                           0x00800000
#define SZ_16M                          0x01000000
#define SZ_32M                          0x02000000
#define SZ_64M                          0x04000000
#define SZ_128M                         0x08000000
#define SZ_256M                         0x10000000

#define SZ_1G                           0x40000000

/* DRAM space */
#define DRAM_BASE                       0x00000000
#define DRAM_DEFAULT                    SZ_16M
#define PCI_DRAMSIZE                    SZ_2M
#define PCI_DRAMBASE                    DRAM_DEFAULT - PCI_DRAMSIZE

/* DC21285 Addresses */

#define DC21285_DRAM_A0MR               0x40000000
#define DC21285_DRAM_A1MR               0x40004000
#define DC21285_DRAM_A2MR               0x40008000
#define DC21285_DRAM_A3MR               0x4000C000
	
#define DC21285_XBUS_XCS0               0x40010000
#define DC21285_XBUS_XCS1               0x40011000
#define DC21285_XBUS_XCS2               0x40012000
#define DC21285_XBUS_NOCS               0x40014000

#define DC21285_FLASH                   0x41000000
/* FLASH base */
#define FLASH_BASE                      DC21285_FLASH
#define FLASH_SIZE                      SZ_4M
#define FLASH_END                       (FLASH_BASE + FLASH_SIZE - 1)
/* ROM is really FLASH on EBSA-285, but you can call it ROM if you want.. */
#define DC21285_ROM                     DC21285_FLASH
/* ROM base */
#define EPROM_BASE                      DC21285_FLASH
#define EPROM_SIZE                      FLASH_SIZE
#define EPROM_END                       (EPROM_BASE + EPROM_SIZE - 1)


#define DC21285_ARMCSR_BASE             0x42000000

#define DC21285_SA_CACHE_FLUSH          0x50000000
/* Reserve Virtual Address for cache flush */
#define CLEAN_BASE                      DC21285_SA_CACHE_FLUSH

#define DC21285_OUTBOUND_WRITE_FLUSH    0x78000000

#define DC21285_ETH100_MEM              0xA0000000

#define DC21285_PCI_IACK                0x79000000
	
#define DC21285_PCI_TYPE_1_CONFIG       0x7A000000

#define DC21285_PCI_TYPE_0_CONFIG       0x7B000000

#define DC21285_PCI_IO                  0x7C000000

#define DC21285_PCI_MEMORY              0x80000000

#define PCI_IO                          DC21285_PCI_IO
#define PCI_MEM                         DC21285_PCI_MEMORY

/*  macro to standardise conversion from ISA (X bus) to sparse address..
 *  and some to standardise conversion from mapped memory to PCI
 */
#define _MapAddress(a)		(((unsigned int) a << 2) | DC21285_XBUS_XCS1)
#define _MapIOAddress(a)	((U32)PCI_IO + (U32)(a))
#define _MapMemAddress(a)	((U32)PCI_MEMORY + (U32)(a))
	

#define COM1Port                        0x3f8
#define COM2Port                        0x2f8		
#define IOShift                         0

/* Serial port constants */
#define XBUS_DEV_0                      DC21285_XBUS_XCS0
#define XBUS_DEV_1                      DC21285_XBUS_XCS1
#define XBUS_DEV_2                      DC21285_XBUS_XCS2
#define XBUS_DEV_3                      DC21285_XBUS_NOCS


/* LED definitions */
#define SA_LED_ON                       0
#define SA_LED_OFF                      1

#define LED_BANK                        XBUS_DEV_2
#define RED_LED                         0x04
#define GREEN_LED                       0x02
#define YELLOW_LED                      0x01
#define ALL_LEDS                        0x07
#define SA_NUM_OF_LEDS                  3
#define SA_LED_MASKS	{ 0, YELLOW_LED, GREEN_LED, RED_LED }
#define SA_LED_OFFSETS	{ 0, (void *)LED_BANK, (void *)LED_BANK, (void *)LED_BANK }
#ifndef HIGH
#define HIGH                            1
#endif


#define CSR_BASE                        DC21285_ARMCSR_BASE

#define PCI_COMMAND                     0x04
#define PCI_MEM_BAR                     0x10
#define PCI_IO_BAR                      0x14
#define PCI_DRAM_BAR                    0x18
#define PCI_OUT_INT_STATUS              0x30
#define PCI_OUT_INT_MASK                0x34
#define MAILBOX_0                       0x50
#define MAILBOX_1                       0x54
#define MAILBOX_2                       0x58
#define MAILBOX_3                       0x5C
#define DOORBELL                        0x60
#define DOORBELL_SETUP                  0x64
#define ROM_BYTE_WRITE                  0x68
#define CHAN_1_BYTE_COUNT               0x80
#define CHAN_1_PCI_ADDR                 0x84
#define CHAN_1_DRAM_ADDR                0x88
#define CHAN_1_DESC_PTR                 0x8C
#define CHAN_1_CONTROL                  0x90
#define CHAN_2_BYTE_COUNT               0xA0
#define CHAN_2_PCI_ADDR                 0xA4
#define CHAN_2_DRAM_ADDR                0xA8
#define CHAN_2_DESC_PTR                 0xAC
#define CHAN_2_CONTROL                  0xB0
#define DRAM_BASE_ADDR_MASK             0x100
#define DRAM_BASE_ADDR_OFF              0x104
#define ROM_BASE_ADDR_MASK              0x108
#define DRAM_TIMING                     0x10C
#define DRAM_ADDR_SIZE_0                0x110
#define DRAM_ADDR_SIZE_1                0x114
#define DRAM_ADDR_SIZE_2                0x118
#define DRAM_ADDR_SIZE_3                0x11C
#define I2O_IFH                         0x120
#define I2O_IPT                         0x124
#define I2O_OPH                         0x128
#define I2O_OFT                         0x12C
#define I2O_IFC                         0x130
#define I2O_OPC                         0x134
#define I2O_IPC                         0x138
#define SA_CONTROL                      0x13C
#define PCI_ADDR_EXT                    0x140
#define PREFETCH_RANGE                  0x144
#define XBUS_CYCLE                      0x148
#define XBUS_STROBE                     0x14C
#define DBELL_PCI_MASK                  0x150
#define DBELL_SA_MASK                   0x154
#define UARTDR                          0x160
#define UMSEOI                          0x164
#define RXSTAT                          0x164 
#define H_UBRLCR                        0x168 
#define M_UBRLCR                        0x16C 
#define L_UBRLCR                        0x170 
#define UARTCON                         0x174 
#define UARTFLG                         0x178 
#define IRQ_STATUS                      0x180 
#define IRQ_RAW_STATUS                  0x184 
#define IRQ_ENABLE                      0x188 
#define IRQ_ENABLE_SET                  0x188 
#define IRQ_ENABLE_CLEAR                0x18C 
#define IRQ_SOFT                        0x190 
#define FIQ_STATUS                      0x280 
#define FIQ_RAW_STATUS                  0x284 
#define FIQ_ENABLE                      0x288 
#define FIQ_ENABLE_SET                  0x288 
#define FIQ_ENABLE_CLEAR                0x28C 
#define FIQ_SOFT                        0x290 
#define TIMER_1_LOAD                    0x300 
#define TIMER_1_VALUE                   0x304 
#define TIMER_1_CONTROL                 0x308 
#define TIMER_1_CLEAR                   0x30C 

#define TIMER_2_LOAD                    0x320 
#define TIMER_2_VALUE                   0x324 
#define TIMER_2_CONTROL                 0x328 
#define TIMER_2_CLEAR                   0x32C 

#define TIMER_3_LOAD                    0x340 
#define TIMER_3_VALUE                   0x344 
#define TIMER_3_CONTROL                 0x348 
#define TIMER_3_CLEAR                   0x34C 

#define TIMER_4_LOAD                    0x360 
#define TIMER_4_VALUE                   0x364 
#define TIMER_4_CONTROL                 0x368 
#define TIMER_4_CLEAR                   0x36C 


/* These are all defined in terms of offsets from DC21285_ARMCSR_BASE */

#define DC21285_ARMCSR_UART_BASE        UARTDR
/* DC21285_UCR			EQU	DC21285_ARMCSR_BASE+0x160
 * DC21285_UDR			EQU	DC21285_ARMCSR_BASE+0x164
 * DC21285_USR			EQU	DC21285_ARMCSR_BASE+0x168
 */
	
#define DC21285_ARMCSR_IRQ_BASE         IRQ_STATUS
/* Offsets from IRQ_BASE, or FIQ_BASE (in words) */
#define INTStatus                       0
#define INTRawStatus                    1
#define INTEnable                       2
#define INTEnableSet                    2
#define INTEnableClear                  3
#define INTSoft                         4

#define DC21285_IRQStatus               DC21285_ARMCSR_BASE+0x180

#define DC21285_ARMCSR_TIMER_BASE       TIMER_1_LOAD
/* Timer enable bit in control register */
#define TIMER_CONTROL_ENABLE            (1 << 7)
#define TIMER_AUTO_RELOAD		(1 << 6)
#define TIMER_PRESCALE_16		4

/* 
 *  Now define individual registers in the clumps.
 * 
 * 
 * 
 */

/* ARM control register constants */
#define INIT_COMPLETE                   1
#define PCI_NRESET                      0x200
#define XCS_2                           0x40000000
#define XCS_1                           0x20000000
#define XCS_0                           0x10000000
#define PCI_CFN                         0x80000000
#define ROM_TIMING                      0x0fff0000
#define ROM_SETUP                       0x04aa0000

/* timer stuff (timer 0) */
#define mSEC_1                          66666000/1000	
#define mSEC_5                          (mSEC_1 * 5)
#define mSEC_10                         (mSEC_1 * 10)
#define SEC_1                           (mSEC_1 * 1000)
#define mSEC_10_from_14			(14318180 + 100)/200

/* video stuff */
#define VIDEO_RAM_BASE			0x88000000

/*
 * What hardware must be present
 */
#define HAS_PCIO

/* PIC irq control */
#define PIC_MASK_LO 0x21
#define PIC_MASK_HI 0xA1
#define PIC_LO 0x20
#define PIC_HI 0xA0

/*
 * IO definitions
 */

/*
 * Mapping areas AFTER mmu is tured on
 */
#define IO_END			0xE2000000
#define IO_BASE			0xe0000000
#define IO_SIZE			(IO_END - IO_BASE)
#define IO_START		0xe0000000
#define IO_BASE_PCI_CONFIG	0xE0100000
#define IO_BASE_ARM_CSR 	0xE1000000
#define IO_BASE_PCI_IACK 	0xE1100000
#define IO_BASE_CACHE_FLUSH	0xE1200000
#define IO_BASE_WRITE_FLUSH	0xE1300000
#define IO_BASE_FLASH		0xE1800000
#define IO_BASE_VGA		0xD0000000
#define IO_BASE_VGA_IO		0xD0800000


/*
 * RAM definitions
 */
#define MAPTOPHYS(a)		((unsigned long)(a) - PAGE_OFFSET)
#define KERNTOPHYS(a)		((unsigned long)(&a))
#define KERNEL_BASE		(0xc0008000)

#endif

